@@ -82,9 +82,10 @@ class Matrix(sym.Matrix):
     # TODO. There is probably a cunning way to automatically handle
     # the following.
 
-    def inv(self, method='ADJ'):
-
-        return self.__class__(sym.Matrix(self).inv(method=method))
+    def inv(self, method='default'):
+        Minv = matrix_inverse(sym.Matrix(self), method=method)
+        
+        return self.__class__(Minv)
 
     def det(self):
 
@@ -155,4 +156,40 @@ def matrix(mat):
     else:
         return mat
 
+
+def matrix_inverse(M, method='default'):
+
+    from .config import matrix_inverse_method, matrix_inverse_fallback_method
+    
+    if method == 'default':
+        method = matrix_inverse_method
+
+    if method == 'GE':
+        try:
+            from sympy.matrices import dotprodsimp 
+            
+            # GE loses it without this assumption.  Well with
+            # sympy-1.6.2 and the master version, GE still loses it
+            # with a poor pivot.
+            with dotprodsimp(False):
+                return M.inv(method='GE')
+        except:
+            return M.inv(method='GE')            
+
+    elif method.startswith('DM-'):
+        try:
+            # This is experimental and requires sympy to be built from
+            # git.  It only works for rational function fields but
+            # fails for polynomial rings.  The latter can be handled
+            # by converting it to a field, however, we just fall back
+            # on a standard method.
+            from sympy.polys.domainmatrix import DomainMatrix
+            dM = DomainMatrix.from_list_sympy(*M.shape, rows=M.tolist())        
+            return dM.inv(method=method[3:]).to_Matrix()            
+        except:
+            method = matrix_inverse_fallback_method
+
+    return M.inv(method=method)
+
+    
 from .expr import Expr, expr
