@@ -39,7 +39,8 @@ from sympy import Derivative, Integral
 __all__ = ('V', 'I', 'v', 'i', 'R', 'L', 'C', 'G', 'Y', 'Z',
            'Vdc', 'Vstep', 'Idc', 'Istep', 'Vac', 'sV', 'sI',
            'Iac', 'Vnoise', 'Inoise', 
-           'Par', 'Ser', 'Xtal', 'FerriteBead', 'CPE', 'series', 'parallel', 'ladder')
+           'Par', 'Ser', 'Xtal', 'FerriteBead', 'CPE', 'series', 'parallel',
+           'ladder')
 
 def _check_oneport_args(args):
 
@@ -307,7 +308,7 @@ class OnePort(Network, ImmittanceMixin):
             return Z(self._Z)
         elif self._Y is not None:
             return Y(self._Y)        
-        raise ValueError('Internal error')
+        raise RuntimeError('Internal error')
 
     def noise_model(self):
         """Convert to noise model."""
@@ -786,11 +787,11 @@ class R(OnePort):
 
     def i_equation(self, v, kind='t'):
 
-        return Current(Voltage(v).select(kind) / self._Z.selectexpr(kind)).select(kind)
+        return Current(Voltage(v).select(kind) / self._Z._selectexpr(kind)).select(kind)
 
     def v_equation(self, i, kind='t'):
 
-        return Voltage(Current(i).select(kind) * self._Z.selectexpr(kind)).select(kind)
+        return Voltage(Current(i).select(kind) * self._Z._selectexpr(kind)).select(kind)
     
 
 class G(OnePort):
@@ -814,11 +815,11 @@ class G(OnePort):
 
     def i_equation(self, v, kind='t'):
 
-        return Current(Voltage(v).select(kind) / self._Z.selectexpr(kind)).select(kind)
+        return Current(Voltage(v).select(kind) / self._Z._selectexpr(kind)).select(kind)
 
     def v_equation(self, i, kind='t'):
 
-        return Voltage(Current(i).select(kind) * self._Z.selectexpr(kind)).select(kind)
+        return Voltage(Current(i).select(kind) * self._Z._selectexpr(kind)).select(kind)
     
 
 class L(OnePort):
@@ -855,13 +856,13 @@ class L(OnePort):
             u = tausym
             v = expr(v).subs(t, u)
             return Current(expr(Integral(v.expr, (u, -oo, tsym))) / self.L).select(kind)
-        return Current(Voltage(v).select(kind) / self.Z.selectexpr(kind)).select(kind)
+        return Current(Voltage(v).select(kind) / self.Z._selectexpr(kind)).select(kind)
 
     def v_equation(self, i, kind='t'):
 
         if kind in ('t', 'time', 'super'):
             return Voltage(self.L * expr(Derivative(i.expr, t))).select(kind)
-        return Voltage(Current(i).select(kind) * self._Z.selectexpr(kind)).select(kind)
+        return Voltage(Current(i).select(kind) * self._Z._selectexpr(kind)).select(kind)
 
     
 class C(OnePort):
@@ -894,7 +895,7 @@ class C(OnePort):
         
         if kind in ('t', 'time', 'super'):
             return Current(self.C * expr(Derivative(v.expr, t))).select(kind)
-        return Current(Voltage(v).select(kind) / self._Z.selectexpr(kind)).select(kind)
+        return Current(Voltage(v).select(kind) / self._Z._selectexpr(kind)).select(kind)
 
     def v_equation(self, i, kind='t'):
 
@@ -904,7 +905,7 @@ class C(OnePort):
             u = tausym
             i = expr(i).subs(t, u)
             return Voltage(expr(Integral(i.expr, (u, -oo, tsym))) / self.C).select(kind)
-        return Voltage(Current(i).select(kind) * self._Z.selectexpr(kind)).select(kind)
+        return Voltage(Current(i).select(kind) * self._Z._selectexpr(kind)).select(kind)
 
 
 class CPE(OnePort):
