@@ -45,7 +45,8 @@ from .expr import Expr
 from . import schemcpts
 import sympy as sym
 from .schemgraph import Graph
-from .schemmisc import Pos, Opts
+from .schemmisc import Pos
+from .opts import Opts
 from .netfile import NetfileMixin
 from .system import run_latex, convert_pdf_png, convert_pdf_svg
 from .system import tmpfilename, circuitikz_version, latex_cleanup
@@ -302,12 +303,12 @@ class Node(object):
     
 class Schematic(NetfileMixin):
 
-    def __init__(self, filename=None, **kwargs):
+    def __init__(self, filename=None, allow_anon=False, **kwargs):
 
         self.elements = OrderedDict()
         self.nodes = {}
         self.hints = False
-        self._init_parser(schemcpts)
+        self._init_parser(schemcpts, allow_anon)
         self.cpt_size = 1.2
         self.node_spacing = 2.0
         self.scale = 1.0
