@@ -579,4 +579,50 @@ class LcapyTester(unittest.TestCase):
         self.assertEqual(expr(Z[0, 1]), expr('R2'), "Z12")                
         self.assertEqual(expr(Z[1, 0]), expr('R2'), "Z21")
         self.assertEqual(expr(Z[1, 1]), expr('R1 + R2'), "Z22")
+
+    def test_in_series(self):
+
+        a = Circuit("""
+        V 1 0 dc
+        R1 1 2
+        R2 2 3
+        R3 3 0
+        R4 3 4
+        R5 4 0""")
+
+        self.assertEqual(a.in_series('R1'), set(('V', 'R1', 'R2')), "in_series(R1)")
+        self.assertEqual(a.in_series('R3'), set(), "in_series(R3)")
+        self.assertEqual(a.in_series('R4'), set(('R4', 'R5')), "in_series(R4)")                
+
+    def test_in_parallel(self):
+        
+        a = Circuit("""
+        V 1 0 dc
+        R1 1 0
+        R2 1 0
+        R3 1 2
+        R4 2 0
+        R5 2 0""")
+
+        self.assertEqual(a.in_parallel('R1'), set(('V', 'R1', 'R2')), "in_parallel(R1)")
+        self.assertEqual(a.in_parallel('R3'), set(), "in_parallel(R3)")
+        self.assertEqual(a.in_parallel('R4'), set(('R4', 'R5')), "in_parallel(R4)")                        
+
+    def test_simplify(self):
+
+        a = Circuit("""
+        R1 1 2
+        R2 2 3""")
+
+        b = a.simplify()
+
+        self.assertEqual(b.impedance(1, 3), a.impedance(1, 3), "simplify series")
+
+        a = Circuit("""
+        R1 1 2
+        R2 1 2""")
+
+        b = a.simplify()
+
+        self.assertEqual(b.impedance(1, 2), a.impedance(1, 2), "simplify parallel")        
         
