@@ -43,7 +43,7 @@ def scale_shift(expr, t):
         return terms[0] / t, sym.S.Zero
 
     scale = terms[0] / t
-    if not scale.is_constant():
+    if scale.has(t):
         raise ValueError('Expression not a scale and shift: %s' % expr)
 
     return scale, terms[1]
@@ -88,3 +88,44 @@ def as_sum(expr, var):
     for term in as_sum_terms(expr, var):
         result += term
     return result
+
+
+def merge_common(lists):
+    # From www.geeksforgeeks.org
+
+    from collections import defaultdict     
+    
+    neighbours = defaultdict(set) 
+    visited = set() 
+    for each in lists: 
+        for item in each: 
+            neighbours[item].update(each) 
+
+    def comp(node, neighbours=neighbours, visited=visited, visit=visited.add): 
+
+        nodes = set([node]) 
+        next_node = nodes.pop 
+        while nodes: 
+            node = next_node() 
+            visit(node) 
+            nodes |= neighbours[node] - visited 
+            yield node
+            
+    for node in neighbours: 
+        if node not in visited: 
+            yield sorted(comp(node))
+  
+
+def equation(expr1, expr2):
+
+    from .expr import Expr
+    
+    class1 = expr1.__class__
+    
+    if isinstance(expr1, Expr):
+        expr1 = expr1.expr
+
+    if isinstance(expr2, Expr):
+        expr2 = expr2.expr
+
+    return class1(sym.Eq(expr1, expr2, evaluate=False))
